@@ -5,6 +5,7 @@ from typing import Any, Dict, List, Optional
 
 from pydantic import BaseModel, Field, constr, root_validator
 
+from mlflow.entities.metric import Metric
 from mlflow.entities.mlfoundry_artifacts import utils
 from mlflow.entities.mlfoundry_artifacts.artifact import (
     _ARTIFACT_VERSION_FQN_FORMAT,
@@ -278,6 +279,7 @@ class ModelVersion(BaseArtifactVersionMixin):
         use_enum_values = True
         allow_mutation = True
         smart_union = True
+        arbitrary_types_allowed = True  # added because `Metric` is not a pydantic model
 
     id: uuid.UUID
     model_id: uuid.UUID
@@ -289,10 +291,12 @@ class ModelVersion(BaseArtifactVersionMixin):
     data_path: Optional[str] = None
     description: Optional[constr(max_length=1024)] = None
     status: ArtifactVersionStatus
-    step: Optional[int] = None
+    step: int = 0
+    metrics: List[Metric] = Field(default_factory=list)
     model_schema: Optional[ModelSchema] = None
     custom_metrics: Optional[List[CustomMetric]] = Field(default_factory=list)
     monitoring_enabled: bool = False
+    run_id: Optional[str] = None  # from events
     created_by: str
     created_at: datetime.datetime
     updated_at: datetime.datetime
@@ -371,9 +375,12 @@ class ModelVersion(BaseArtifactVersionMixin):
             created_at=self.created_at.astimezone(tz=datetime.timezone.utc).isoformat(),
             updated_at=self.updated_at.astimezone(tz=datetime.timezone.utc).isoformat(),
             model_schema=self.model_schema.to_proto() if self.model_schema else None,
+            run_id=self.run_id,
         )
         if self.custom_metrics:
             model_version.custom_metrics.extend([cm.to_proto() for cm in self.custom_metrics])
+        if self.metrics:
+            model_version.metrics.extend([metric.to_proto() for metric in self.metrics])
         return model_version
 
     @classmethod
@@ -384,13 +391,18 @@ class ModelVersion(BaseArtifactVersionMixin):
         monitoring_enabled = get_field_if_set(message, "monitoring_enabled", default=False)
         data_path = get_field_if_set(message, "data_path", default=None)
         description = get_field_if_set(message, "description", default=None)
-        step = get_field_if_set(message, "step", default=None)
+        step = get_field_if_set(message, "step", default=0)
+        if step is None:
+            step = 0
         model_schema = get_field_if_set(message, "model_schema", default=None)
         if model_schema:
             model_schema = ModelSchema.from_proto(model_schema)
         custom_metrics = [CustomMetric.from_proto(cm) for cm in message.custom_metrics]
+        run_id = get_field_if_set(message, "run_id", default=None)
+        metrics = [Metric.from_proto(metric) for metric in message.metrics]
         return cls(
             id=uuid.UUID(message.id),
+            metrics=metrics,
             model_id=uuid.UUID(message.model_id),
             model_fqn=message.model_fqn,
             experiment_id=int(message.experiment_id),
@@ -404,6 +416,7 @@ class ModelVersion(BaseArtifactVersionMixin):
             model_schema=model_schema,
             custom_metrics=custom_metrics,
             monitoring_enabled=monitoring_enabled,
+            run_id=run_id,
             created_by=message.created_by,
             created_at=datetime.datetime.fromisoformat(message.created_at),
             updated_at=datetime.datetime.fromisoformat(message.updated_at),
