@@ -591,7 +591,7 @@ class AbstractStore:
         raise NotImplementedError()
 
     @_err_if_not_exist_wrapper("...")
-    def get_model(
+    def get_model_by_name(
         self,
         experiment_id: int,
         name: str,
