@@ -494,7 +494,7 @@ class RestStore(AbstractStore):
         # this is only `Optional` because argument default should be {}
         artifact_metadata: typing.Optional[typing.Dict[str, typing.Any]] = None,
         data_path: typing.Optional[str] = None,
-        step: typing.Optional[int] = None,
+        step: int = 0,
         # unused args
         created_by: typing.Optional[str] = None,
     ) -> ArtifactVersion:
