@@ -66,15 +66,11 @@ class TrackingServiceClient:
         :param tracking_uri: Address of local or remote tracking server.
         """
         self.tracking_uri = tracking_uri
-        # NB: Fetch the tracking store (`self.store`) upon client initialization to ensure that
-        # the tracking URI is valid and the store can be properly resolved. We define `store` as a
-        # property method to ensure that the client is serializable, even if the store is not
-        # self.store  # pylint: disable=pointless-statement
-        self.store
+        self._store = utils._get_store(self.tracking_uri)
 
     @property
     def store(self) -> TrackingStore:
-        return utils._get_store(self.tracking_uri)
+        return self._store
 
     def get_run(self, run_id):
         """
@@ -563,7 +559,7 @@ class TrackingServiceClient:
         # this is only `Optional` because argument default should be {}
         artifact_metadata: typing.Optional[typing.Dict[str, typing.Any]] = None,
         data_path: typing.Optional[str] = None,
-        step: typing.Optional[int] = None,
+        step: int = 0,
     ) -> ArtifactVersion:
         return self.store.finalize_artifact_version(
             version_id=version_id,
